@@ -1,6 +1,6 @@
 /* database-common.hpp -- Common specs for AppStream Xapian database
  *
- * Copyright (C) 2012 Matthias Klumpp
+ * Copyright (C) 2012-2013 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 3
  *
@@ -24,34 +24,27 @@
 namespace AppStream {
 
 // values used in the database
+namespace XapianValues {
+
 enum XapianValues {
 	APPNAME = 170,
-	PKGNAME = 171,
-	ICON = 172,
-	GETTEXT_DOMAIN = 173,
-	ARCHIVE_SECTION = 174,
-	ARCHIVE_ARCH = 175,
-	POPCON = 176,
-	SUMMARY = 177,
-	ARCHIVE_CHANNEL = 178,
-	DESKTOP_FILE = 179,
-	PRICE = 180,
-	ARCHIVE_PPA = 181,
-	ARCHIVE_DEB_LINE = 182,
-	ARCHIVE_SIGNING_KEY_ID = 183,
-	PURCHASED_DATE = 184,
-	SCREENSHOT_URLS = 185,		// multiple urls, comma seperated
-	SC_DESCRIPTION = 188,
-	APPNAME_UNTRANSLATED = 189,
-	ICON_URL = 190,
-	CATEGORIES = 191,
-	LICENSE_KEY = 192,
-	LICENSE = 194,
-	VIDEO_URL = 195,
-	DATE_PUBLISHED = 196,
-	SUPPORT_SITE_URL = 197,
-	VERSION_INFO = 198,
-	SC_SUPPORTED_DISTROS = 199
+	APPNAME_UNTRANSLATED = 171,
+	DESKTOP_FILE = 172,
+	PKGNAME = 173,
+	ICON = 174,
+	ICON_URL = 175,
+	SUMMARY = 176,
+	DESCRIPTION = 177,
+	SCREENSHOTS = 178,	// screenshot definitions, as XML
+	CATEGORIES = 179,
+	LICENSE = 180,
+	URL_HOMEPAGE = 181,
+
+	GETTEXT_DOMAIN = 190,
+	ARCHIVE_SECTION = 191,
+	ARCHIVE_CHANNEL = 192
+};
+
 };
 
 // weights for the different fields
